@@ -38,8 +38,8 @@
 #include <libgnomeprint/gnome-print-frgba.h>
 
 /* For the buffer stuff, remove when the buffer stuff is moved out here */
-#include <sys/mman.h>
 #include <sys/types.h>
+#include <sys/mman.h>
 #include <sys/stat.h>
 #include <fcntl.h>
 #include <unistd.h>
@@ -101,7 +101,7 @@ gnome_print_context_finalize (GObject *object)
 	pc = GNOME_PRINT_CONTEXT (object);
 
 	if (pc->transport) {
-		g_warning ("file %s: line %d: Destorying Context with open transport", __FILE__, __LINE__);
+		g_warning ("file %s: line %d: Destroying Context with open transport", __FILE__, __LINE__);
 		g_object_unref (G_OBJECT (pc->transport));
 		pc->transport = NULL;
 	}
@@ -234,6 +234,39 @@ gnome_print_showpage (GnomePrintContext *pc)
 	return ret;
 }
 
+/**
+ * gnome_print_end_doc:
+ * @pc: A #GnomePrintContext
+ *
+ * to be called at the end of any copy of the document before the next 
+ * copy starts. It will do such things as ejecting a page in duplex printing.
+ * 
+ * 
+ * 
+ * 
+ *
+ * Returns: #GNOME_PRINT_OK or positive value on success, negative error
+ * code on failure.
+ */
+int
+gnome_print_end_doc (GnomePrintContext *pc)
+{
+	gint ret;
+
+	g_return_val_if_fail (pc != NULL, GNOME_PRINT_ERROR_BADCONTEXT);
+	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (pc), 
+			      GNOME_PRINT_ERROR_BADCONTEXT);
+	g_return_val_if_fail (pc->gc != NULL, GNOME_PRINT_ERROR_BADCONTEXT);
+	g_return_val_if_fail (!pc->haspage, GNOME_PRINT_ERROR_NOMATCH);
+
+	ret = GNOME_PRINT_OK;
+
+	if (GNOME_PRINT_CONTEXT_GET_CLASS (pc)->end_doc)
+		ret = GNOME_PRINT_CONTEXT_GET_CLASS (pc)->end_doc (pc);
+
+	return ret;
+}
+
 /**
  * gnome_print_gsave:
  * @pc: A #GnomePrintContext
